@@ -1,22 +1,23 @@
-#' Alpha scales.
+#' Alpha transparency scales
 #'
+#' Alpha-transparency scales are not tremendously useful, but can be a
+#' convenient way to visually down-weight less important observations.
 #' \code{scale_alpha} is an alias for \code{scale_alpha_continuous} since
 #' that is the most common use of alpha, and it saves a bit of typing.
 #'
 #' @param ... Other arguments passed on to \code{\link{continuous_scale}}
 #'   or \code{\link{discrete_scale}} as appropriate, to control name, limits,
 #'   breaks, labels and so forth.
-#' @param range range of output alpha values.  Should lie between 0 and 1.
+#' @param range Output range of alpha values. Must lie between 0 and 1.
+#' @family colour scales
 #' @export
 #' @examples
-#' (p <- qplot(mpg, cyl, data = mtcars, alpha = cyl))
+#' p <- ggplot(mpg, aes(displ, hwy)) +
+#'   geom_point(aes(alpha = year))
+#'
+#' p
 #' p + scale_alpha("cylinders")
-#' p + scale_alpha("number\nof\ncylinders")
-#'
 #' p + scale_alpha(range = c(0.4, 0.8))
-#'
-#' (p <- qplot(mpg, cyl, data=mtcars, alpha = factor(cyl)))
-#' p + scale_alpha_discrete(range = c(0.4, 0.8))
 scale_alpha <- function(..., range = c(0.1, 1)) {
   continuous_scale("alpha", "alpha_c", rescale_pal(range), ...)
 }
@@ -29,5 +30,5 @@ scale_alpha_continuous <- scale_alpha
 #' @export
 scale_alpha_discrete <- function(..., range = c(0.1, 1)) {
   discrete_scale("alpha", "alpha_d",
-    function(n) seq(range[1], range[2], length = n), ...)
+    function(n) seq(range[1], range[2], length.out = n), ...)
 }
